Authors:

* Peter Amstutz <peter.amstutz@curii.com>, Arvados Project, Curii Corporation
* Michael R. Crusoe <mrc@commonwl.org>, Common Workflow Language
  project

Contributors:

* Brad Chapman <bchapman@hsph.harvard.edu>, Harvard Chan School of Public Health
* John Chilton <jmchilton@gmail.com>, Galaxy Project, Pennsylvania State University
* Bogdan Gavrilovic <bogdan.gavrilovic@sbgenomics.com>, Seven Bridges Genomics
* Kaushik Ghose, Seven Bridges Genomics, Inc; https://orcid.org/0000-0003-2933-1260
* Dan Leehr <dan.leehr@duke.edu>, Duke University
* Hervé Ménager <herve.menager@gmail.com>, Institut Pasteur
* Maya Nedeljkovich <maja.nedeljkovic@sbgenomics.com>, Seven Bridges Genomics
* Matt Scales <mscales@icr.ac.uk>, Institute of Cancer Research, London
* Stian Soiland-Reyes <soiland-reyes@cs.manchester.ac.uk>, University of Manchester
* Luka Stojanovic <luka.stojanovic@sbgenomics.com>, Seven Bridges Genomics

This specification was [approved on 6 June 2019](https://github.com/common-workflow-language/common-workflow-language/issues/861) by the CWL leadership team consisting of:

* Peter Amstutz, Curoverse Inc. / Arvados; https://orcid.org/0000-0003-3566-7705
* John Chilton, Pennsylvania State University / Galaxy Project; https://orcid.org/0000-0002-6794-0756
* Michael R. Crusoe, CWL Project Lead; https://orcid.org/0000-0002-2961-9670
* Brandi Davis Dusenbery, Seven Bridges Genomics, Inc.; https://orcid.org/0000-0001-7811-8613
* Jeff Gentry, Broad Institute; https://orcid.org/0000-0001-5351-8442
* Hervé Ménager, Institut Pasteur; https://orcid.org/0000-0002-7552-1009
* Stian Soiland-Reyes, University of Manchester; https://orcid.org/0000-0001-9842-9718
